@@ -13,7 +13,12 @@
 #include <QThread>
 #include <QUrl>
 
+#include <QApplication>
+
 #include <KLocalizedString>
+#include <KIO/FileCopyJob>
+#include <KIO/StoredTransferJob>
+#include <KJobWidgets>
 
 #include "skanpage_debug.h"
 
@@ -153,14 +158,16 @@ void DocumentModel::exportPDF(const QUrl &fileUrl, const QString &title, const b
 
 void DocumentModel::addImage(const QImage &image)
 {
-    const double aspectRatio = static_cast<double>(image.height()) / image.width();
-    beginInsertRows(QModelIndex(), d->m_pages.count(), d->m_pages.count());
-    const PreviewPageProperties newPage = {aspectRatio, 500, static_cast<int>(500 * aspectRatio), d->m_idCounter, false};
     const int oldSize = d->m_nonSavedPages.size();
     d->m_nonSavedPages.insert(d->m_idCounter);
     if (oldSize == 0 && d->m_nonSavedPages.size() > 0) {
         Q_EMIT isReadyChanged(false);
     }
+
+    const double aspectRatio = static_cast<double>(image.height()) / image.width();
+    beginInsertRows(QModelIndex(), d->m_pages.count(), d->m_pages.count());
+    const PreviewPageProperties newPage = {aspectRatio, 500, static_cast<int>(500 * aspectRatio), d->m_idCounter, false};
+
     d->m_idCounter++;
     qCDebug(SKANPAGE_LOG) << "Inserting new page into model:" << newPage;
     d->m_details.append(newPage);
@@ -424,8 +431,27 @@ void DocumentModel::clearData()
     }
 }
 
-void DocumentModel::updateFileInformation(const QList<QUrl> &fileUrls, const SkanpageUtils::DocumentPages &document)
+void DocumentModel::updateFileInformation(const QList<QUrl> &fileUrls, const QList<QString> &localNames, const SkanpageUtils::DocumentPages &document)
 {
+    for (int i = 0; i < fileUrls.count(); i++) {
+        if (!fileUrls.at(i).isLocalFile()) {
+            QFile file(localNames.at(i));
+            bool okOpen = file.open(QIODevice::ReadOnly);
+            if (!okOpen) {
+                qCDebug(SKANPAGE_LOG) << "Failed to open local file during copying to remote location.";
+            }
+            const auto copyJob = KIO::storedPut(&file, fileUrls.at(i), -1, KIO::HideProgressInfo | KIO::Overwrite);
+            KJobWidgets::setWindow(copyJob, QApplication::activeWindow());
+            bool okCopy = copyJob->exec();
+
+            if (!okCopy) {
+                file.close();
+                file.remove();
+                qCDebug(SKANPAGE_LOG) << "Failed to copy file to remote location.";
+                return;
+            }
+        }
+    }
     if (document == d->m_pages && d->m_changed) {
         d->m_changed = false;
         Q_EMIT changedChanged();
