@@ -6,10 +6,10 @@
 
 #include "FormatModel.h"
 
-#include <QImageWriter>
 #include <QImageReader>
-#include <QMimeType>
+#include <QImageWriter>
 #include <QMimeDatabase>
+#include <QMimeType>
 
 #include <KLocalizedString>
 
@@ -18,7 +18,7 @@ class FormatModelPrivate
 public:
     QList<QMimeType> m_writeFormatList;
     QVariantList m_writeFormatFilter;
-    QVariantList m_readFormatFilter;
+    QVariant m_readFormatFilterConcatenated;
 };
 
 FormatModel::FormatModel(QObject *parent)
@@ -26,43 +26,38 @@ FormatModel::FormatModel(QObject *parent)
     , d(std::make_unique<FormatModelPrivate>())
 {
     const QMimeDatabase mimeDB;
-    QList<QByteArray> tempWriteList = QImageWriter::supportedMimeTypes();
+    QList<QByteArray> tempList;
+    tempList = QImageWriter::supportedMimeTypes();
     // Put first class citizens at first place
-    tempWriteList.removeAll(QByteArray("image/jpeg"));
-    tempWriteList.removeAll(QByteArray("image/png"));
-    int count = tempWriteList.removeAll(QByteArray("image/tiff")); // TIFF is not on the base list of formats
-    tempWriteList.insert(0, QByteArray("application/pdf"));
-    tempWriteList.insert(1, QByteArray("image/png"));
-    tempWriteList.insert(2, QByteArray("image/jpeg"));
-    if (count > 0) {
-        tempWriteList.insert(3, QByteArray("image/tiff"));
+    tempList.removeAll(QByteArray("image/jpeg"));
+    tempList.removeAll(QByteArray("image/png"));
+    tempList.removeAll(QByteArray("application/pdf"));
+
+    tempList.insert(0, QByteArray("application/pdf"));
+    tempList.insert(1, QByteArray("image/png"));
+    tempList.insert(2, QByteArray("image/jpeg"));
+
+    for (const auto &mimeString : std::as_const(tempList)) {
+        const QMimeType mimeType = mimeDB.mimeTypeForName(QString::fromLatin1(mimeString));
+        if (mimeType.isValid()) {
+            d->m_writeFormatList.append(mimeType);
+            // craft a string that QML's FileDialog understands
+            d->m_writeFormatFilter.append({mimeType.comment() + QStringLiteral("(*.") + mimeType.preferredSuffix() + QStringLiteral(")")});
+        }
     }
 
-    for (const auto &mimeString : std::as_const(tempWriteList)) {
+    // create a concatenated read filter for import dialog
+    tempList = QImageReader::supportedMimeTypes();
+    QString readFormatFilter = i18nc("format filter for a file dialog, all formats supported by the application will be displayed", "All Supported Files");
+    readFormatFilter.append(QStringLiteral(" ("));
+    for (const auto &mimeString : std::as_const(tempList)) {
         const QMimeType mimeType = mimeDB.mimeTypeForName(QString::fromLatin1(mimeString));
-        d->m_writeFormatList.append(mimeType);
-        // craft a string that QML's FileDialog understands
-        d->m_writeFormatFilter.append({mimeType.comment() + QStringLiteral("(*.") + mimeType.preferredSuffix() + QStringLiteral(")")});
-    }
-    QList<QByteArray> tempReadList = QImageReader::supportedMimeTypes();
-    tempReadList.removeAll(QByteArray("image/jpeg"));
-    tempReadList.removeAll(QByteArray("image/tiff"));
-    tempReadList.removeAll(QByteArray("image/png"));
-    tempReadList.insert(0, QByteArray("image/png"));
-    tempReadList.insert(1, QByteArray("image/jpeg"));
-    tempReadList.insert(2, QByteArray("image/tiff"));
-    d->m_readFormatFilter.append({i18n("All files") + QStringLiteral(" (*)")});
-    for (const auto &mimeString : std::as_const(tempReadList)) {
-        const QMimeType mimeType = mimeDB.mimeTypeForName(QString::fromLatin1(mimeString));
-        // craft a string that QML's FileDialog understands
-        const auto &suffixes = mimeType.suffixes();
-        QString filter = QStringLiteral("(");
-        for (const auto &suffix : suffixes) {
-            filter.append(QStringLiteral("*.") + suffix + QStringLiteral(" "));
+        if (mimeType.isValid()) {
+            readFormatFilter.append(QStringLiteral(" *.") + mimeType.preferredSuffix());
         }
-        filter.append(QStringLiteral(")"));
-        d->m_readFormatFilter.append({mimeType.comment() + filter});
     }
+    readFormatFilter.append(QStringLiteral(" )"));
+    d->m_readFormatFilterConcatenated = readFormatFilter;
 }
 
 FormatModel::~FormatModel()
@@ -123,14 +118,14 @@ QVariantList FormatModel::writeFormatFilter() const
     return d->m_writeFormatFilter;
 }
 
-QVariantList FormatModel::importFormatFilter() const
-{
-    return d->m_readFormatFilter;
-}
-
 QString FormatModel::pdfFormatFilter() const
 {
     return d->m_writeFormatFilter.at(0).toString();
 }
 
+QVariant FormatModel::readFormatFilterConcatenated() const
+{
+    return d->m_readFormatFilterConcatenated;
+}
+
 #include "moc_FormatModel.cpp"
