@@ -18,13 +18,18 @@ class FormatModel : public QAbstractListModel
     Q_OBJECT
 
 public:
-    enum FormatModelRoles { NameRole = Qt::UserRole + 1, SuffixRole, CommentRole, NameFilterRole};
+    enum FormatModelRoles {
+        NameRole = Qt::UserRole + 1,
+        SuffixRole,
+        CommentRole,
+        NameFilterRole
+    };
 
     Q_ENUM(FormatModelRoles)
 
     explicit FormatModel(QObject *parent = nullptr);
 
-    ~FormatModel();
+    ~FormatModel() override;
 
     QHash<int, QByteArray> roleNames() const override;
 
@@ -36,13 +41,12 @@ public:
 
     Q_INVOKABLE QVariantList writeFormatFilter() const;
 
-    Q_INVOKABLE QVariantList importFormatFilter() const;
-
     Q_INVOKABLE QString pdfFormatFilter() const;
 
+    Q_INVOKABLE QVariant readFormatFilterConcatenated() const;
+
 private:
     std::unique_ptr<FormatModelPrivate> d;
 };
 
-
 #endif // FORMAT_MODEL_H
