@@ -72,7 +72,7 @@ public:
     };
     Q_ENUM(ScanSplit)
 
-    explicit Skanpage(const QString &deviceName, const QUrl &dumpOptionsUrl, QObject *parent = nullptr);
+    explicit Skanpage(const QString &deviceName, const QUrl &dumpOptionUrl, const QUrl &importUrl, QObject *parent = nullptr);
     ~Skanpage() override;
 
     QString deviceVendor() const;
@@ -105,7 +105,6 @@ public:
     Q_INVOKABLE void cancelScan();
     Q_INVOKABLE void reloadDevicesList();
     Q_INVOKABLE bool openDevice(const QString &deviceName, const QString &deviceVendor = QString(), const QString &deviceModel = QString());
-    Q_INVOKABLE bool OCRavailable() const;
     Q_INVOKABLE void print();
     Q_INVOKABLE void registerAction(QObject *item, QObject *shortcuts, const QString &iconText);
     Q_INVOKABLE void showShortcutsDialog();
@@ -130,20 +129,19 @@ Q_SIGNALS:
 private Q_SLOTS:
 
     void imageReady(const QImage &image);
+    void previewImageReady(const QImage &image);
     void availableDevices(const QList<KSaneCore::DeviceInformation *> &deviceList);
     void showKSaneMessage(KSaneCore::Interface::ScanStatus type, const QString &strStatus);
     void showUserMessage(SkanpageUtils::MessageLevel level, const QString &strStatus);
     void progressUpdated(int progress);
     void batchModeCountDown(int remainingSeconds);
     void scanningFinished(KSaneCore::Interface::ScanStatus status, const QString &strStatus);
-    void imageTemporarilySaved();
+    void checkFinish();
 
 private:
     void finishOpeningDevice(const QString &deviceName, const QString &deviceVendor, const QString &deviceModel);
     void loadScannerOptions();
     void saveScannerOptions();
-    void checkFinish();
-    void finishPreview();
     void setupScanningBounds();
     void signalErrorMessage(const QString &text);
 
